/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIFontEnumerator.idl
 */

#ifndef __gen_nsIFontEnumerator_h__
#define __gen_nsIFontEnumerator_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIFontEnumerator */
#define NS_IFONTENUMERATOR_IID_STR "a6cf9114-15b3-11d2-932e-00805f8add32"

#define NS_IFONTENUMERATOR_IID \
  {0xa6cf9114, 0x15b3, 0x11d2, \
    { 0x93, 0x2e, 0x00, 0x80, 0x5f, 0x8a, 0xdd, 0x32 }}

class NS_NO_VTABLE nsIFontEnumerator : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IFONTENUMERATOR_IID)

  /**
   * Return a sorted array of the names of all installed fonts.
   *
   * @param  aCount     returns number of names returned
   * @param  aResult    returns array of names
   * @return void
   */
  /* void EnumerateAllFonts (out PRUint32 aCount, [array, size_is (aCount), retval] out wstring aResult); */
  NS_IMETHOD EnumerateAllFonts(PRUint32 *aCount, PRUnichar ***aResult) = 0;

  /**
   * Return a sorted array of names of fonts that support the given language
   * group and are suitable for use as the given CSS generic font.
   *
   * @param  aLangGroup language group
   * @param  aGeneric   CSS generic font
   * @param  aCount     returns number of names returned
   * @param  aResult    returns array of names
   * @return void
   */
  /* void EnumerateFonts (in string aLangGroup, in string aGeneric, out PRUint32 aCount, [array, size_is (aCount), retval] out wstring aResult); */
  NS_IMETHOD EnumerateFonts(const char *aLangGroup, const char *aGeneric, PRUint32 *aCount, PRUnichar ***aResult) = 0;

  /* void HaveFontFor (in string aLangGroup, [retval] out boolean aResult); */
  NS_IMETHOD HaveFontFor(const char *aLangGroup, PRBool *aResult) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFONTENUMERATOR \
  NS_IMETHOD EnumerateAllFonts(PRUint32 *aCount, PRUnichar ***aResult); \
  NS_IMETHOD EnumerateFonts(const char *aLangGroup, const char *aGeneric, PRUint32 *aCount, PRUnichar ***aResult); \
  NS_IMETHOD HaveFontFor(const char *aLangGroup, PRBool *aResult); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFONTENUMERATOR(_to) \
  NS_IMETHOD EnumerateAllFonts(PRUint32 *aCount, PRUnichar ***aResult) { return _to ## EnumerateAllFonts(aCount, aResult); } \
  NS_IMETHOD EnumerateFonts(const char *aLangGroup, const char *aGeneric, PRUint32 *aCount, PRUnichar ***aResult) { return _to ## EnumerateFonts(aLangGroup, aGeneric, aCount, aResult); } \
  NS_IMETHOD HaveFontFor(const char *aLangGroup, PRBool *aResult) { return _to ## HaveFontFor(aLangGroup, aResult); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFONTENUMERATOR(_to) \
  NS_IMETHOD EnumerateAllFonts(PRUint32 *aCount, PRUnichar ***aResult) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##-> EnumerateAllFonts(aCount, aResult); } \
  NS_IMETHOD EnumerateFonts(const char *aLangGroup, const char *aGeneric, PRUint32 *aCount, PRUnichar ***aResult) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##-> EnumerateFonts(aLangGroup, aGeneric, aCount, aResult); } \
  NS_IMETHOD HaveFontFor(const char *aLangGroup, PRBool *aResult) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##-> HaveFontFor(aLangGroup, aResult); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFontEnumerator : public nsIFontEnumerator
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFONTENUMERATOR

  nsFontEnumerator();
  virtual ~nsFontEnumerator();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFontEnumerator, nsIFontEnumerator)

nsFontEnumerator::nsFontEnumerator()
{
  NS_INIT_ISUPPORTS();
  /* member initializers and constructor code */
}

nsFontEnumerator::~nsFontEnumerator()
{
  /* destructor code */
}

/* void EnumerateAllFonts (out PRUint32 aCount, [array, size_is (aCount), retval] out wstring aResult); */
NS_IMETHODIMP nsFontEnumerator::EnumerateAllFonts(PRUint32 *aCount, PRUnichar ***aResult)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void EnumerateFonts (in string aLangGroup, in string aGeneric, out PRUint32 aCount, [array, size_is (aCount), retval] out wstring aResult); */
NS_IMETHODIMP nsFontEnumerator::EnumerateFonts(const char *aLangGroup, const char *aGeneric, PRUint32 *aCount, PRUnichar ***aResult)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void HaveFontFor (in string aLangGroup, [retval] out boolean aResult); */
NS_IMETHODIMP nsFontEnumerator::HaveFontFor(const char *aLangGroup, PRBool *aResult)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFontEnumerator_h__ */
